@@ -172,10 +172,6 @@ impl App {
             flags.insert(NeedsUpdate::COMMANDS);
         } else if let Event::Key(k) = ev {
             let new_flags = match k {
-                keys::EXIT_1 | keys::EXIT_2 => {
-                    self.do_quit = true;
-                    NeedsUpdate::empty()
-                }
                 keys::FOCUS_WORKDIR => {
                     self.switch_focus(Focus::WorkDir)
                 }
@@ -206,6 +202,8 @@ impl App {
             flags.insert(new_flags);
         }
 
+        self.check_quit(ev);
+
         let new_flags = self.process_queue();
         flags.insert(new_flags);
 
@@ -298,6 +296,14 @@ impl App {
         None
     }
 
+    fn check_quit(&mut self, ev: Event) {
+        if let Event::Key(e) = ev {
+            if let keys::EXIT = e {
+                self.do_quit = true;
+            }
+        }
+    }
+
     fn toggle_tabs(&mut self) {
         self.tab += 1;
         self.tab %= 2;
@@ -415,6 +421,15 @@ impl App {
             );
         }
 
+        res.push(
+            CommandInfo::new(
+                commands::TOGGLE_TABS,
+                true,
+                !self.any_popup_visible(),
+            )
+            .hidden(),
+        );
+
         res.push(
             CommandInfo::new(
                 commands::QUIT,
