@@ -348,8 +348,7 @@ impl Component for ChangesComponent {
                         }
                         true
                     }
-                    keys::STATUS_RESET_FILE_1
-                    | keys::STATUS_RESET_FILE_2 => {
+                    keys::STATUS_RESET_FILE => {
                         self.is_working_dir
                             && self.dispatch_reset_workdir()
                     }
@@ -359,6 +358,9 @@ impl Component for ChangesComponent {
                     keys::MOVE_UP => {
                         self.move_selection(MoveSelection::Up)
                     }
+                    keys::HOME | keys::SHIFT_UP => {
+                        self.move_selection(MoveSelection::Home)
+                    }
                     keys::MOVE_LEFT => {
                         self.move_selection(MoveSelection::Left)
                     }
