@@ -1,11 +1,12 @@
-use super::{CommandBlocking, DrawableComponent};
+use super::{CommandBlocking, DrawableComponent, ScrollType};
 use crate::{
     components::{CommandInfo, Component},
+    keys,
     queue::{InternalEvent, Queue},
     strings,
 };
 use asyncgit::{hash, DiffLine, DiffLineType, FileDiff};
-use crossterm::event::{Event, KeyCode};
+use crossterm::event::Event;
 use std::{borrow::Cow, cmp, convert::TryFrom};
 use strings::commands;
 use tui::{
@@ -86,15 +87,25 @@ impl DiffComponent {
         }
     }
 
-    fn scroll(&mut self, inc: bool) {
+    fn scroll(&mut self, scroll: ScrollType) {
         let old = self.scroll;
-        if inc {
-            self.scroll = cmp::min(
-                self.diff.lines.saturating_sub(1),
-                self.scroll.saturating_add(1),
-            );
-        } else {
-            self.scroll = self.scroll.saturating_sub(1);
+
+        let scroll_max = self.diff.lines.saturating_sub(1);
+
+        match scroll {
+            ScrollType::Down => {
+                self.scroll = cmp::min(
+                    scroll_max,
+                    self.scroll.saturating_add(1),
+                );
+            }
+
+            ScrollType::Up => {
+                self.scroll = self.scroll.saturating_sub(1);
+            }
+
+            ScrollType::Home => self.scroll = 0,
+            ScrollType::End => self.scroll = scroll_max,
         }
 
         if old != self.scroll {
@@ -293,11 +304,13 @@ impl DrawableComponent for DiffComponent {
             style_title = style_title.modifier(Modifier::BOLD);
         }
 
+        let title =
+            format!("{}{}", strings::TITLE_DIFF, self.current.path);
         f.render_widget(
             Paragraph::new(self.get_text(r.width, r.height).iter())
                 .block(
                     Block::default()
-                        .title(strings::TITLE_DIFF)
+                        .title(title.as_str())
                         .borders(Borders::ALL)
                         .border_style(style_border)
                         .title_style(style_title),
@@ -320,16 +333,24 @@ impl Component for DiffComponent {
             self.focused,
         ));
 
-        let cmd_text = if self.current.is_stage {
-            commands::DIFF_HUNK_REMOVE
-        } else {
-            commands::DIFF_HUNK_ADD
-        };
+        out.push(
+            CommandInfo::new(
+                commands::DIFF_HOME_END,
+                self.can_scroll(),
+                self.focused,
+            )
+            .hidden(),
+        );
 
         out.push(CommandInfo::new(
-            cmd_text,
+            commands::DIFF_HUNK_REMOVE,
             self.selected_hunk.is_some(),
-            self.focused,
+            self.focused && self.current.is_stage,
+        ));
+        out.push(CommandInfo::new(
+            commands::DIFF_HUNK_ADD,
+            self.selected_hunk.is_some(),
+            self.focused && !self.current.is_stage,
         ));
 
         CommandBlocking::PassingOn
@@ -338,16 +359,26 @@ impl Component for DiffComponent {
     fn event(&mut self, ev: Event) -> bool {
         if self.focused {
             if let Event::Key(e) = ev {
-                return match e.code {
-                    KeyCode::Down => {
-                        self.scroll(true);
+                return match e {
+                    keys::MOVE_DOWN => {
+                        self.scroll(ScrollType::Down);
                         true
                     }
-                    KeyCode::Up => {
-                        self.scroll(false);
+                    keys::SHIFT_DOWN | keys::END => {
+                        self.scroll(ScrollType::End);
                         true
                     }
-                    KeyCode::Enter => {
+
+                    keys::HOME | keys::SHIFT_UP => {
+                        self.scroll(ScrollType::Home);
+                        true
+                    }
+
+                    keys::MOVE_UP => {
+                        self.scroll(ScrollType::Up);
+                        true
+                    }
+                    keys::ENTER => {
                         self.add_hunk();
                         true
                     }
