@@ -1,5 +1,5 @@
 pub static TITLE_STATUS: &str = "Unstaged Changes [1]";
-pub static TITLE_DIFF: &str = "Diff";
+pub static TITLE_DIFF: &str = "Diff: ";
 pub static TITLE_INDEX: &str = "Staged Changes [2]";
 
 pub static TAB_STATUS: &str = "Status";
@@ -24,6 +24,12 @@ pub mod commands {
     static CMD_GROUP_CHANGES: &str = "Changes";
     static CMD_GROUP_COMMIT: &str = "Commit";
 
+    ///
+    pub static TOGGLE_TABS: CommandText = CommandText::new(
+        "Tabs [tabs]",
+        "switch top level tabs",
+        CMD_GROUP_GENERAL,
+    );
     ///
     pub static HELP_OPEN: CommandText = CommandText::new(
         "Help [h]",
@@ -43,6 +49,12 @@ pub mod commands {
         CMD_GROUP_GENERAL,
     );
     ///
+    pub static DIFF_HOME_END: CommandText = CommandText::new(
+        "Jump up/down [home,end,shift+up,shift+down]",
+        "scroll to top or bottom of diff",
+        CMD_GROUP_DIFF,
+    );
+    ///
     pub static DIFF_HUNK_ADD: CommandText = CommandText::new(
         "Add hunk [enter]",
         "adds selected hunk to stage",
@@ -130,7 +142,7 @@ pub mod commands {
     );
     ///
     pub static QUIT: CommandText = CommandText::new(
-        "Quit [esc,q]",
+        "Quit [ctrl+c]",
         "quit gitui application",
         CMD_GROUP_GENERAL,
     );
