@@ -1,5 +1,7 @@
 use crate::{
-    components::{CommandBlocking, CommandInfo, Component},
+    components::{
+        CommandBlocking, CommandInfo, Component, ScrollType,
+    },
     keys,
     strings::commands,
 };
@@ -8,7 +10,7 @@ use chrono::prelude::*;
 use crossbeam_channel::Sender;
 use crossterm::event::Event;
 use std::{borrow::Cow, cmp, convert::TryFrom, time::Instant};
-use sync::CommitInfo;
+use sync::{CommitInfo, Tags};
 use tui::{
     backend::Backend,
     layout::{Alignment, Rect},
@@ -24,29 +26,32 @@ struct LogEntry {
     hash: String,
 }
 
-impl From<&CommitInfo> for LogEntry {
-    fn from(c: &CommitInfo) -> Self {
+impl From<CommitInfo> for LogEntry {
+    fn from(c: CommitInfo) -> Self {
         let time =
             DateTime::<Local>::from(DateTime::<Utc>::from_utc(
                 NaiveDateTime::from_timestamp(c.time, 0),
                 Utc,
             ));
         Self {
-            author: c.author.clone(),
-            msg: c.message.clone(),
+            author: c.author,
+            msg: c.message,
             time: time.format("%Y-%m-%d %H:%M:%S").to_string(),
-            hash: c.hash[0..7].to_string(),
+            hash: c.hash,
         }
     }
 }
 
 const COLOR_SELECTION_BG: Color = Color::Blue;
 
+const STYLE_TAG: Style = Style::new().fg(Color::Yellow);
 const STYLE_HASH: Style = Style::new().fg(Color::Magenta);
 const STYLE_TIME: Style = Style::new().fg(Color::Blue);
 const STYLE_AUTHOR: Style = Style::new().fg(Color::Green);
 const STYLE_MSG: Style = Style::new().fg(Color::Reset);
 
+const STYLE_TAG_SELECTED: Style =
+    Style::new().fg(Color::Yellow).bg(COLOR_SELECTION_BG);
 const STYLE_HASH_SELECTED: Style =
     Style::new().fg(Color::Magenta).bg(COLOR_SELECTION_BG);
 const STYLE_TIME_SELECTED: Style =
@@ -56,7 +61,7 @@ const STYLE_AUTHOR_SELECTED: Style =
 const STYLE_MSG_SELECTED: Style =
     Style::new().fg(Color::Reset).bg(COLOR_SELECTION_BG);
 
-static ELEMENTS_PER_LINE: usize = 8;
+static ELEMENTS_PER_LINE: usize = 10;
 static SLICE_SIZE: usize = 1000;
 static SLICE_OFFSET_RELOAD_THRESHOLD: usize = 100;
 
@@ -69,6 +74,7 @@ pub struct Revlog {
     visible: bool,
     first_open_done: bool,
     scroll_state: (Instant, f32),
+    tags: Tags,
 }
 
 impl Revlog {
@@ -82,6 +88,7 @@ impl Revlog {
             visible: false,
             first_open_done: false,
             scroll_state: (Instant::now(), 0_f32),
+            tags: Tags::new(),
         }
     }
 
@@ -94,7 +101,12 @@ impl Revlog {
 
         let mut txt = Vec::new();
         for (idx, e) in self.items.iter().enumerate() {
-            Self::add_entry(e, idx == selection, &mut txt);
+            let tag = if let Some(tag_name) = self.tags.get(&e.hash) {
+                tag_name.as_str()
+            } else {
+                ""
+            };
+            Self::add_entry(e, idx == selection, &mut txt, tag);
         }
 
         let title =
@@ -138,12 +150,17 @@ impl Revlog {
             );
 
             if let Ok(commits) = commits {
-                self.items.extend(commits.iter().map(LogEntry::from));
+                self.items
+                    .extend(commits.into_iter().map(LogEntry::from));
             }
         }
+
+        if self.tags.is_empty() {
+            self.tags = sync::get_tags(CWD).unwrap();
+        }
     }
 
-    fn move_selection(&mut self, up: bool) {
+    fn move_selection(&mut self, scroll: ScrollType) {
         self.update_scroll_speed();
 
         #[allow(clippy::cast_possible_truncation)]
@@ -151,11 +168,16 @@ impl Revlog {
             .unwrap()
             .max(1);
 
-        if up {
-            self.selection = self.selection.saturating_sub(speed_int);
-        } else {
-            self.selection = self.selection.saturating_add(speed_int);
-        }
+        self.selection = match scroll {
+            ScrollType::Up => {
+                self.selection.saturating_sub(speed_int)
+            }
+            ScrollType::Down => {
+                self.selection.saturating_add(speed_int)
+            }
+            ScrollType::Home => 0,
+            _ => self.selection,
+        };
 
         self.selection = cmp::min(self.selection, self.selection_max);
 
@@ -190,6 +212,7 @@ impl Revlog {
         e: &'a LogEntry,
         selected: bool,
         txt: &mut Vec<Text<'a>>,
+        tag: &'a str,
     ) {
         let count_before = txt.len();
 
@@ -204,7 +227,7 @@ impl Revlog {
         };
 
         txt.push(Text::Styled(
-            Cow::from(e.hash.as_str()),
+            Cow::from(&e.hash[0..7]),
             if selected {
                 STYLE_HASH_SELECTED
             } else {
@@ -229,6 +252,19 @@ impl Revlog {
                 STYLE_AUTHOR
             },
         ));
+        txt.push(splitter.clone());
+        txt.push(Text::Styled(
+            Cow::from(if tag.is_empty() {
+                String::from("")
+            } else {
+                format!(" {}", tag)
+            }),
+            if selected {
+                STYLE_TAG_SELECTED
+            } else {
+                STYLE_TAG
+            },
+        ));
         txt.push(splitter);
         txt.push(Text::Styled(
             Cow::from(e.msg.as_str()),
@@ -249,11 +285,15 @@ impl Component for Revlog {
         if let Event::Key(k) = ev {
             return match k {
                 keys::MOVE_UP => {
-                    self.move_selection(true);
+                    self.move_selection(ScrollType::Up);
                     true
                 }
                 keys::MOVE_DOWN => {
-                    self.move_selection(false);
+                    self.move_selection(ScrollType::Down);
+                    true
+                }
+                keys::SHIFT_UP | keys::HOME => {
+                    self.move_selection(ScrollType::Home);
                     true
                 }
                 _ => false,
